package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseInspectProject;
import com.aucma.dms.service.IDmsBaseInspectProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 巡检项目信息Controller
 *
 * @author Open Platform
 * @date 2024-01-17
 */
@RestController
@RequestMapping("/dms/dmsBaseInspectProject")
public class DmsBaseInspectProjectController extends BaseController
{
    @Autowired
    private IDmsBaseInspectProjectService dmsBaseInspectProjectService;

    /**
     * 查询巡检项目信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectProject:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseInspectProject dmsBaseInspectProject)
    {
        startPage();
        List<DmsBaseInspectProject> list = dmsBaseInspectProjectService.selectDmsBaseInspectProjectList(dmsBaseInspectProject);
        return getDataTable(list);
    }

    /**
     * 查询巡检线路项目
     */
    @GetMapping("/getdmsBaseInspectProjectList")
    public AjaxResult getdmsBaseInspectProjectList(DmsBaseInspectProject dmsBaseInspectProject)
    {
        List<DmsBaseInspectProject> list = dmsBaseInspectProjectService
                .selectDmsBaseInspectProjectList(dmsBaseInspectProject);
        return success(list);
    }
    /**
     * 导出巡检项目信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectProject:export')" )
    ////@Log(title = "巡检项目信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseInspectProject dmsBaseInspectProject)
    {
        List<DmsBaseInspectProject> list = dmsBaseInspectProjectService.selectDmsBaseInspectProjectList(dmsBaseInspectProject);
        ExcelUtil<DmsBaseInspectProject> util = new ExcelUtil<DmsBaseInspectProject>(DmsBaseInspectProject.class);
        util.exportExcel(response, list, "巡检项目信息数据");
    }

    /**
     * 获取巡检项目信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectProject:query')" )
    @GetMapping(value = "/{inspectProjectId}")
    public AjaxResult getInfo(@PathVariable("inspectProjectId") Long inspectProjectId)
    {
        return success(dmsBaseInspectProjectService.selectDmsBaseInspectProjectByInspectProjectId(inspectProjectId));
    }

    /**
     * 新增巡检项目信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectProject:add')" )
    ////@Log(title = "巡检项目信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseInspectProject dmsBaseInspectProject)
    {
        return toAjax(dmsBaseInspectProjectService.insertDmsBaseInspectProject(dmsBaseInspectProject));
    }

    /**
     * 修改巡检项目信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectProject:edit')" )
    ////@Log(title = "巡检项目信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseInspectProject dmsBaseInspectProject)
    {
        return toAjax(dmsBaseInspectProjectService.updateDmsBaseInspectProject(dmsBaseInspectProject));
    }

    /**
     * 删除巡检项目信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectProject:remove')" )
    ////@Log(title = "巡检项目信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{inspectProjectIds}")
    public AjaxResult remove(@PathVariable Long[] inspectProjectIds)
    {
        return toAjax(dmsBaseInspectProjectService.deleteDmsBaseInspectProjectByInspectProjectIds(inspectProjectIds));
    }
}
